# -*- coding: utf-8 -*-
'''*****************************************************************************
***  This file is part of HgWeb Manager.                                     ***
***                                                                          ***
***  Copyright (C) 2014                                                      ***
***  CodeGNU Solutions <Licensing _AT_ CodeGNU _DOT_ com>                    ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*****************************************************************************'''


class Manager(object):
	""" Manages the configurations for HgWebManager """

	# The configuration file parser.
	__parser = None
	# The absolute directory path and file name of the hg command.
	__hgCommand = None
	# The absolute directory path to the managed HgWeb repositories.
	__repositoryPath = None
	# The absolute directory path to the HgWeb web-server.
	__hgWebPath = None
	# The user-name of the Mercurial web-manager.
	__hgUser = None

	@property
	def HgCommand(self):
		""" Gets the command for executing mercurial. """
		return self.__hgCommand

	@property
	def RepositoryPath(self):
		""" Gets the directory path to the managed repositories. """
		return self.__repositoryPath

	@property
	def HgWebPath(self):
		""" Gets the directory path to the repository web-server. """
		return self.__hgWebPath

	@property
	def HgUser(self):
		""" Gets the user-name of the web-manager. """
		return self.__hgUser

	def __init__(self, path=['/etc/hwm.ini', '~/.hwm/hwm.ini', './hwm.ini']):
		""" Loads the settings values stored in the configuration file.

		@param[in] path	The path and file name of the configuration file.

		@throws ConfigParser.Error		When the configuration file cannot be
										found.
		"""
		from ConfigParser import SafeConfigParser, Error

		self.__parser = SafeConfigParser()
		if not self.__parser.read(path):
			raise Error("Failed to find configuration file.")

		if self.__parser.has_section('Mercurial'):
			if self.__parser.has_option('Mercurial', 'Base'):
				self.__repositoryPath = self.__parser.get('Mercurial', 'Base')

			if self.__parser.has_option('Mercurial', 'Command'):
				self.__hgCommand = self.__parser.get('Mercurial', 'Command')

			if self.__parser.has_option('Mercurial', 'User'):
				self.__hgUser = self.__parser.get('Mercurial', 'User')

			if self.__parser.has_option('Mercurial', 'Web'):
				self.__hgWebPath = self.__parser.get('Mercurial', 'Web')
		else:
			self.__hgUser = "hg"
			self.__repositoryPath = "/var/hg/repos"
			self.__hgCommand = "/usr/bin/hg"
			self.__hgWebPath = "/var/www/hgweb"
